@@ -11,7 +11,7 @@
 #' @importFrom stats hclust dist cor
 #' @importFrom normaliseR normalise
 #' @param x \code{feature_calculations} object containing the raw feature matrix produced by \code{theft::calculate_features}
-#' @param type \code{character} specifying the type of plot to draw. Defaults to \code{"quality"}
+#' @param type \code{character} specifying the type of plot to draw. Can be one of \code{"matrix"}, \code{"cor"}, \code{"violin"}, \code{"box"}, or \code{"quality"}. Defaults to \code{"matrix"}
 #' @param norm_method \code{character} specifying a rescaling/normalising method to apply if \code{type = "matrix"} or if \code{type = "cor"}. Can be one of \code{"zScore"}, \code{"Sigmoid"}, \code{"RobustSigmoid"}, \code{"MinMax"}, or \code{"MaxAbs"}. Defaults to \code{"zScore"}
 #' @param unit_int \code{Boolean} whether to rescale into unit interval \code{[0,1]} after applying normalisation method. Defaults to \code{FALSE}
 #' @param clust_method \code{character} specifying the hierarchical clustering method to use if \code{type = "matrix"} or if \code{type = "cor"}. Defaults to \code{"average"}
@@ -23,7 +23,7 @@
 #' @export
 #'
 
-plot.feature_calculations <- function(x, type = c("quality", "matrix", "cor", "violin"),
+plot.feature_calculations <- function(x, type = c("matrix", "cor", "violin", "box", "quality"),
                                       norm_method = c("zScore", "Sigmoid", "RobustSigmoid", "MinMax", "MaxAbs"),
                                       unit_int = FALSE,
                                       clust_method = c("average", "ward.D", "ward.D2", "single", "complete", "mcquitty", "median", "centroid"),
@@ -235,7 +235,7 @@ plot.feature_calculations <- function(x, type = c("quality", "matrix", "cor", "v
       p <- p +
         ggplot2::theme(axis.text = ggplot2::element_blank())
     }
-  } else{
+  } else if(type == "violin"){
 
     if(is.null(feature_names)){
       stop("feature_names argument must not be NULL if drawing a violin plot. Please enter a vector of valid feature names.")
@@ -266,6 +266,36 @@ plot.feature_calculations <- function(x, type = c("quality", "matrix", "cor", "v
     }
   }
 
+  else{
+
+    if(is.null(feature_names)){
+      stop("feature_names argument must not be NULL if drawing a boxplot Please enter a vector of valid feature names.")
+    } else{
+      p <- x %>%
+        dplyr::filter(names %in% feature_names) %>%
+        dplyr::mutate(names = paste0(.data$feature_set, "_", .data$names))
+
+      if("group" %in% colnames(p)){
+        p <- p %>%
+          ggplot2::ggplot(ggplot2::aes(x = .data$group, y = .data$values, colour = .data$group))
+      } else{
+        p <- p %>%
+          dplyr::mutate(group = "Data") %>%
+          ggplot2::ggplot(ggplot2::aes(x = .data$group, y = .data$values))
+      }
+
+      p <- p +
+        ggplot2::geom_boxplot(...) +
+        ggplot2::labs(x = "Class",
+                      y = "Feature value") +
+        ggplot2::scale_colour_brewer(palette = "Dark2") +
+        ggplot2::theme_bw() +
+        ggplot2::theme(legend.position = "none",
+                       axis.text.x = ggplot2::element_text(angle = 90)) +
+        ggplot2::facet_wrap(~ names, scales = "free_y")
+    }
+  }
+
   return(p)
 }
 
@@ -465,3 +495,36 @@ plot.feature_projection <- function(x, show_covariance = TRUE, ...){
 
   return(p)
 }
+
+#------------------------- interval_calculations object methods -------------------------
+
+#' Produce a plot for a interval_calculations object
+#'
+#' @importFrom rlang .data
+#' @import dplyr
+#' @importFrom ggplot2 ggplot aes geom_errorbar geom_point labs scale_colour_brewer theme_bw theme element_blank
+#' @param x \code{interval_calculations} object containing the summary calculated by \code{interval}
+#' @param ... Arguments to be passed to methods
+#' @return object of class \code{ggplot} that contains the graphic
+#' @author Trent Henderson
+#' @export
+#'
+
+plot.interval_calculations <- function(x, ...){
+
+  stopifnot(inherits(x, "interval_calculations") == TRUE)
+
+  p <- x %>%
+    ggplot2::ggplot(ggplot2::aes(x = reorder(.data$feature_set, -.data$.mean), y = .data$.mean,
+                                 colour = .data$feature_set)) +
+    ggplot2::geom_errorbar(ggplot2::aes(ymin = .data$.lower, ymax = .data$.upper)) +
+    ggplot2::geom_point(size = 5) +
+    ggplot2::labs(x = "Feature set",
+                  y = "Classification accuracy") +
+    ggplot2::scale_colour_brewer(palette = "Dark2") +
+    ggplot2::theme_bw() +
+    ggplot2::theme(legend.position = "none",
+                   panel.grid.minor = ggplot2::element_blank())
+
+  print(p)
+}
